/*

    __SECURE_Driver.h

    Copyright (c) 2011-2017 MikroElektronika.  All right reserved.

------------------------------------------------------------------------------*/

/**
@file           __SECURE_HAL.h
@brief                         SECURE Click
   
@mainpage SECURE Click
@{

### Device Description ###

    ${CLICK_INFO}

@}

@defgroup    SECURE
@brief       SECURE Click Driver
@{

- Global Library Prefix : **SECURE**
- Version               : **1.0.0**
- Date                  : **May 2017.**
- Developer             : *Milos Vidojevic*

    ${LIBRARY_DESCRIPTION}


*//*--------------------------------------------------------------------------*/
/**
    @example Click_SECURE_ARM_STM.c
    @example Click_SECURE_ARM_TIVA.c
    @example Click_SECURE_ARM_CEC.c
    @example Click_SECURE_ARM_KIN.c
    @example Click_SECURE_ARM_MSP.c
    @example Click_SECURE_PIC.c
    @example Click_SECURE_PIC32.c
    @example Click_SECURE_DSPIC.c
    @example Click_SECURE_AVR.c
    @example Click_SECURE_FTDI.c
    @example Click_SECURE_ARM_STM.mbas
    @example Click_SECURE_ARM_TIVA.mbas
    @example Click_SECURE_ARM_CEC.mbas
    @example Click_SECURE_ARM_KIN.mbas
    @example Click_SECURE_ARM_MSP.mbas
    @example Click_SECURE_PIC.mbas
    @example Click_SECURE_PIC32.mbas
    @example Click_SECURE_DSPIC.mbas
    @example Click_SECURE_AVR.mbas
    @example Click_SECURE_FTDI.mbas
    @example Click_SECURE_ARM_STM.mpas
    @example Click_SECURE_ARM_TIVA.mpas
    @example Click_SECURE_ARM_CEC.mpas
    @example Click_SECURE_ARM_KIN.mpas
    @example Click_SECURE_ARM_MSP.mpas
    @example Click_SECURE_PIC.pas
    @example Click_SECURE_PIC32.pas
    @example Click_SECURE_DSPIC.pas
    @example Click_SECURE_AVR.pas
    @example Click_SECURE_FTDI.pas

*//*--------------------------------------------------------------------------*/

#ifndef _SECURE_H_
#define _SECURE_H_

#include <stdint.h>

/*-------------------------------------------------------------- HAL POINTERS */
#if defined( __MIKROC_PRO_FOR_ARM__ )
    #if defined( __STM32__ ) || defined( __KINETIS__ ) || defined( __MCHP__ )

typedef unsigned int ( *T_SECURE_I2C_Start )();
typedef unsigned int ( *T_SECURE_I2C_Write )(unsigned char slave_address,
                                                    unsigned char *buffer, 
                                                    unsigned long count, 
                                                    unsigned long end_mode);
typedef void ( *T_SECURE_I2C_Read )(unsigned char slave_address, 
                                           unsigned char *buffer,
                                           unsigned long count, 
                                           unsigned long end_mode);
    #elif defined( __MSP__ )

typedef unsigned int ( *T_SECURE_I2C_Write )(unsigned char slave_address,
                                                    unsigned char *buffer,
                                                    unsigned long count, 
                                                    unsigned long end_mode);

typedef void ( *T_SECURE_I2C_Read )(unsigned char slave_address, 
                                           unsigned char *buffer, 
                                           unsigned long count, 
                                           unsigned long end_mode);

    #elif defined( __TI__ )

typedef void ( *T_SECURE_I2C_SetSlaveAddress )(char slave_address,
                                                      char dir);

typedef unsigned char ( *T_SECURE_I2C_Write )(unsigned char data_in, 
                                                     unsigned char mode);
typedef unsigned char( *T_SECURE_I2C_Read )(unsigned char *data_out, 
                                                   unsigned char mode);
    #endif

#elif  defined( __MIKROC_PRO_FOR_AVR__ )

typedef unsigned char( *T_SECURE_I2C_Start )();
typedef void  ( *T_SECURE_I2C_Stop )();
typedef void ( *T_SECURE_I2C_Close )();
typedef void ( *T_SECURE_I2C_Write )(unsigned char data_out);
typedef unsigned char ( *T_SECURE_I2C_Read )(unsigned char ack);

#elif  defined( __MIKROC_PRO_FOR_PIC__ )

typedef unsigned char( *T_SECURE_I2C_Start )();
typedef void ( *T_SECURE_I2C_Stop )();
typedef void ( *T_SECURE_I2C_Restart )();
typedef unsigned char( *T_SECURE_I2C_Write )(unsigned char data_out);
typedef unsigned char( *T_SECURE_I2C_Read )(unsigned char ack);

#elif defined( __MIKROC_PRO_FOR_PIC32__ )

typedef unsigned int ( *T_SECURE_I2C_Idle )();
typedef unsigned int ( *T_SECURE_I2C_Start )();
typedef void ( *T_SECURE_I2C_Stop )();
typedef unsigned int ( *T_SECURE_I2C_Restart )();
typedef unsigned int ( *T_SECURE_I2C_Write )(unsigned char data_out);
typedef unsigned char ( *T_SECURE_I2C_Read )(unsigned int ack);

#elif defined( __MIKROC_PRO_FOR_DSPIC__ )

typedef unsigned int ( *T_SECURE_I2C_Start )();
typedef void ( *T_SECURE_I2C_Stop )();
typedef void ( *T_SECURE_I2C_Restart )();
typedef unsigned int ( *T_SECURE_I2C_Write )(unsigned char data_out);
typedef unsigned char ( *T_SECURE_I2C_Read )(unsigned int ack);

#elif defined( __MIKROC_PRO_FOR_8051__ )

typedef unsigned char( *T_SECURE_I2C_Start )();
typedef void ( *T_SECURE_I2C_Stop )();
typedef void ( *T_SECURE_I2C_Write )(unsigned char data_out);
typedef unsigned char( *T_SECURE_I2C_Read )(unsigned char ack);

#elif defined( __MIKROC_PRO_FOR_FT90x__ )

typedef void ( *T_SECURE_I2C_SetSlaveAddress )
                                                  (unsigned char slave_address);
typedef unsigned char ( *T_SECURE_I2C_Write )(unsigned char *buffer, 
                                                     unsigned int count);
typedef unsigned char ( *T_SECURE_I2C_Read )(unsigned char *buffer, 
                                                    unsigned int count);
#endif
/*----------------------------------------------------------------------------*/

/**
 * @name                 SECURE Click Registers
 *//*-------------------------------------------------------------------------*/
///@{

#define _SECURE_STATUS

///@}
/**
 * @name                 SECURE Click Return Values
 *//*-------------------------------------------------------------------------*/
///@{

#define _SECURE_OK (0)
#define _SECURE_ERR (-1)

///@}
/**
 * @name                 SECURE Click Types
 *//*-------------------------------------------------------------------------*/
///@{

//typedef struct atcaI2Cmaster {
//    twi_master_t i2c_master_instance;
//    int ref_ct;
//    // for conveniences during interface release phase
//    int bus_index;
//} ATCAI2CMaster_t;

//void change_i2c_speed( ATCAIface iface, uint32_t speed );

typedef struct
{
#if defined( __MIKROC_PRO_FOR_ARM__ )
    #if defined( __STM32__ ) || defined( __KINETIS__ ) || defined( __MCHP__ )
        T_SECURE_I2C_Start              fStart;
        T_SECURE_I2C_Write              fWrite;
        T_SECURE_I2C_Read               fRead;
    #elif defined( __MSP__ )
        T_SECURE_I2C_Write              fWrite;
        T_SECURE_I2C_Read               fRead;
    #elif defined( __TI__ )
        T_SECURE_I2C_SetSlaveAddress    fSetSlaveAddr;
        T_SECURE_I2C_Write              fWrite;
        T_SECURE_I2C_Read               fRead;
    #endif
#elif defined( __MIKROC_PRO_FOR_AVR__ )   || \
      defined( __MIKROC_PRO_FOR_8051__ )  || \
      defined( __MIKROC_PRO_FOR_DSPIC__ ) || \
      defined( __MIKROC_PRO_FOR_PIC32__ ) || \
      defined( __MIKROC_PRO_FOR_PIC__ )
        T_SECURE_I2C_Start              fStart;
        T_SECURE_I2C_Stop               fStop;
        T_SECURE_I2C_Write              fWrite;
        T_SECURE_I2C_Read               fRead;
#elif defined( __MIKROC_PRO_FOR_FT90x__ )
        T_SECURE_I2C_SetSlaveAddress    fSetSlaveAddr;
        T_SECURE_I2C_Write              fWrite;
        T_SECURE_I2C_Read               fRead;
#endif

}T_SECURE_hal;

///@}
/**
 * @name                 SECURE Click Driver Functions
 *//*-------------------------------------------------------------------------*/
///@{
#ifdef __cplusplus
extern "C"{
#endif

void SECURE_HAL_init
(
#if defined( __MIKROC_PRO_FOR_ARM__ )
    #if defined( __STM32__ ) || defined( __KINETIS__ ) || defined( __MCHP__ )

        uint8_t slaveAddress,
        T_SECURE_I2C_Start fpStart,
        T_SECURE_I2C_Write fpWrite, T_SECURE_I2C_Read fpRead
    #elif defined( __MSP__ )

        uint8_t slaveAddress,
        T_SECURE_I2C_Write fpWrite, T_SECURE_I2C_Read fpRead
    #elif defined( __TI__ )

        uint8_t slaveAddress,
        T_SECURE_I2C_SetSlaveAddress fpSlaveAddr,
        T_SECURE_I2C_Write fpWrite, T_SECURE_I2C_Read fpRead
    #endif

#elif defined( __MIKROC_PRO_FOR_AVR__ )   || \
      defined( __MIKROC_PRO_FOR_8051__ )  || \
      defined( __MIKROC_PRO_FOR_DSPIC__ ) || \
      defined( __MIKROC_PRO_FOR_PIC32__ ) || \
      defined( __MIKROC_PRO_FOR_PIC__ )

        uint8_t slaveAddress,
        T_SECURE_I2C_Start fpStart, T_SECURE_I2C_Stop fpStop,
        T_SECURE_I2C_Write fpWrite, T_SECURE_I2C_Read fpRead

#elif defined( __MIKROC_PRO_FOR_FT90x__ )

        uint8_t slaveAddress, T_SECURE_I2C_SetSlaveAddress fpSlaveAddr,
        T_SECURE_I2C_Write fpWrite, T_SECURE_I2C_Read fpRead
#endif
);

#ifdef __cplusplus
} // extern "C"
#endif
#endif
///@}
///@}
/*------------------------------------------------------------------------------

  __SECURE_HAL.h

  Copyright (c) 2011-2017 MikroElektronika.  All right reserved.

    This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

------------------------------------------------------------------------------*/